@@ -1,15 +1,15 @@
 package Sort::Sub;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-25'; # DATE
-our $DIST = 'Sort-Sub'; # DIST
-our $VERSION = '0.120'; # VERSION
-
 use 5.010001;
 use strict 'subs', 'vars';
 use warnings;
 use Log::ger;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-07-17'; # DATE
+our $DIST = 'Sort-Sub'; # DIST
+our $VERSION = '0.121'; # VERSION
+
 our $re_spec = qr/\A(\$)?(\w+)(?:<(\w*)>)?\z/;
 
 our %argsopt_sortsub = (
@@ -75,7 +75,8 @@ sub get_sorter {
     my ($is_var, $name, $opts) = $spec =~ $re_spec
         or die "Invalid sorter spec '$spec', please use: ".
         '[$]NAME [ <OPTS> ]';
-    require "Sort/Sub/$name.pm";
+    my $modpm = "Sort/Sub/$name.pm";
+    require $modpm;
     $opts //= "";
     my $is_reverse = $opts =~ /r/;
     my $is_ci      = $opts =~ /i/;
@@ -131,7 +132,7 @@ Sort::Sub - Collection of sort subroutines
 
 =head1 VERSION
 
-This document describes version 0.120 of Sort::Sub (from Perl distribution Sort-Sub), released on 2020-05-25.
+This document describes version 0.121 of Sort::Sub (from Perl distribution Sort-Sub), released on 2024-07-17.
 
 =head1 SYNOPSIS
 
@@ -260,14 +261,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sort-Sub>.
 
 Source repository is at L<https://github.com/perlancar/perl-Sort-Sub>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sort-Sub>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 Other additional C<Sort::Sub::*> not bundled in this distribution.
@@ -279,11 +272,37 @@ L<App::sorted>), CLI's from L<App::SortSubUtils>.
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2024, 2020, 2019, 2018, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sort-Sub>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
