@@ -1,14 +1,14 @@
 package Sort::Sub::by_ascii_then_num;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-25'; # DATE
-our $DIST = 'Sort-Sub'; # DIST
-our $VERSION = '0.120'; # VERSION
-
 use 5.010;
 use strict;
 use warnings;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-07-17'; # DATE
+our $DIST = 'Sort-Sub'; # DIST
+our $VERSION = '0.121'; # VERSION
+
 sub meta {
     return {
         v => 1,
@@ -26,7 +26,7 @@ sub gen_sorter {
                        \z/x;
 
     sub {
-        no strict 'refs';
+        no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
 
         my $caller = caller();
         my $a = @_ ? $_[0] : ${"$caller\::a"};
@@ -66,7 +66,7 @@ Sort::Sub::by_ascii_then_num - Sort non-numbers (sorted asciibetically) before n
 
 =head1 VERSION
 
-This document describes version 0.120 of Sort::Sub::by_ascii_then_num (from Perl distribution Sort-Sub), released on 2020-05-25.
+This document describes version 0.121 of Sort::Sub::by_ascii_then_num (from Perl distribution Sort-Sub), released on 2024-07-17.
 
 =for Pod::Coverage ^(gen_sorter|meta)$
 
@@ -108,14 +108,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sort-Sub>.
 
 Source repository is at L<https://github.com/perlancar/perl-Sort-Sub>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sort-Sub>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Sort::Sub>
@@ -124,11 +116,37 @@ L<Sort::Sub>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2024, 2020, 2019, 2018, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sort-Sub>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
