@@ -1,10 +1,5 @@
 package Sort::Sub::by_first_num_in_text;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-25'; # DATE
-our $DIST = 'Sort-Sub'; # DIST
-our $VERSION = '0.120'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -12,6 +7,11 @@ require Sort::Sub::by_num_in_text;
 *gen_sorter = \&Sort::Sub::by_num_in_text::gen_sorter;
 *meta       = \&Sort::Sub::by_num_in_text::meta;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-07-17'; # DATE
+our $DIST = 'Sort-Sub'; # DIST
+our $VERSION = '0.121'; # VERSION
+
 1;
 # ABSTRACT: Sort by first number found in text or (if no number is found) ascibetically
 
@@ -27,7 +27,7 @@ Sort::Sub::by_first_num_in_text - Sort by first number found in text or (if no n
 
 =head1 VERSION
 
-This document describes version 0.120 of Sort::Sub::by_first_num_in_text (from Perl distribution Sort-Sub), released on 2020-05-25.
+This document describes version 0.121 of Sort::Sub::by_first_num_in_text (from Perl distribution Sort-Sub), released on 2024-07-17.
 
 =for Pod::Coverage ^(gen_sorter|meta)$
 
@@ -69,14 +69,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sort-Sub>.
 
 Source repository is at L<https://github.com/perlancar/perl-Sort-Sub>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sort-Sub>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Sort::Sub>
@@ -87,11 +79,37 @@ L<Sort::Sub::by_num_in_text>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2024, 2020, 2019, 2018, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sort-Sub>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
