@@ -2,11 +2,6 @@
 
 package Test::Sort::Sub;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-25'; # DATE
-our $DIST = 'Sort-Sub'; # DIST
-our $VERSION = '0.120'; # VERSION
-
 use 5.010001;
 use strict 'subs', 'vars';
 use warnings;
@@ -15,6 +10,11 @@ use Exporter 'import';
 use Sort::Sub ();
 use Test::More 0.98;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-07-17'; # DATE
+our $DIST = 'Sort-Sub'; # DIST
+our $VERSION = '0.121'; # VERSION
+
 our @EXPORT = qw(sort_sub_ok);
 
 sub _sort {
@@ -72,7 +72,7 @@ Test::Sort::Sub - Test Sort::Sub::* subroutine
 
 =head1 VERSION
 
-This document describes version 0.120 of Test::Sort::Sub (from Perl distribution Sort-Sub), released on 2020-05-25.
+This document describes version 0.121 of Test::Sort::Sub (from Perl distribution Sort-Sub), released on 2024-07-17.
 
 =head1 FUNCTIONS
 
@@ -86,6 +86,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sort-Sub>.
 
 Source repository is at L<https://github.com/perlancar/perl-Sort-Sub>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2024, 2020, 2019, 2018, 2016, 2015 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sort-Sub>
@@ -94,15 +123,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020, 2019, 2018, 2016, 2015 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
